#
# spec file for package maven-file-management
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maven-file-management
Version:        3.1.0
Release:        1.3
Summary:        Maven File Management API
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/shared/file-management
Source0:        https://repo1.maven.org/maven2/org/apache/maven/shared/file-management/%{version}/file-management-%{version}-source-release.zip
Source1:        %{name}-build.xml
BuildRequires:  ant
BuildRequires:  apache-commons-io
BuildRequires:  fdupes
BuildRequires:  javapackages-local >= 6
BuildRequires:  maven-lib
BuildRequires:  modello >= 2.0.0
BuildRequires:  plexus-utils
BuildRequires:  plexus-xml
BuildRequires:  slf4j
BuildRequires:  unzip
BuildArch:      noarch

%description
Provides a component for plugins to easily resolve project dependencies.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.

%prep
%setup -q -n file-management-%{version}
cp %{SOURCE1} build.xml

%pom_add_dep org.codehaus.plexus:plexus-xml:3.0.0

%build
mkdir -p lib
build-jar-repository -s lib \
    commons-io \
    maven/maven-plugin-api \
    plexus/utils \
    plexus/xml \
    slf4j/api

%{ant} \
    jar javadoc

%install
# jar
install -dm 0755 %{buildroot}%{_javadir}/%{name}
install -pm 0644 target/file-management-%{version}.jar %{buildroot}%{_javadir}/%{name}/file-management.jar
# pom
install -dm 0755 %{buildroot}%{_mavenpomdir}/%{name}
%{mvn_install_pom} pom.xml %{buildroot}%{_mavenpomdir}/%{name}/file-management.pom
%add_maven_depmap %{name}/file-management.pom %{name}/file-management.jar
# javadoc
install -dm 0755 %{buildroot}%{_javadocdir}/%{name}
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/%{name}/
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE NOTICE

%files javadoc
%{_javadocdir}/%{name}
%license LICENSE NOTICE

%changelog
* Wed Jun 12 2024 Fridrich Strba <fstrba@suse.com>
- Update to upstream version 3.1.0
  * Changes:
    + remove vestigial file
    + deps: update JUnit
    + ignore .checkstyle
    + update plexus-utils
    + Remove dependency on maven-shared-io
    + Use try with resources
    + Remove deprecated methods in favor of Apache Commons IO
    + MSHARED-1090: Update module
* Thu May 16 2024 Fridrich Strba <fstrba@suse.com>
- Use sisu-plexus instead of plexus-containers-container-default
* Tue Apr  2 2024 Fridrich Strba <fstrba@suse.com>
- Add dependency on plexus-xml where relevant
  * this will be needed for smooth upgrade to plexus-utils 4.0.0
* Wed Sep  6 2023 Fridrich Strba <fstrba@suse.com>
- Remove unnecessary dependency on xmvn tools and parent pom
* Fri May 13 2022 Fridrich Strba <fstrba@suse.com>
- Fix build with modello 2.0.0
* Mon Mar 21 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
* Tue Mar 26 2019 Fridrich Strba <fstrba@suse.com>
- Initial packaging of maven-file-management 3.0.0
- Generate and customize ant build.xml file
